==> aeon-0.4.0.tar.gz: aeon-0.4.0/docs/examples.md <==
# Examples

## Forecasting

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: /examples/forecasting/img/forecasting2.png
:link: /examples/forecasting/forecasting.ipynb
:link-type: ref
:text-align: center

Forecasting overview

:::

:::{grid-item-card}
:img-top: examples/forecasting/img/proba.png
:link: /examples/forecasting/forecasting_proba.ipynb
:link-type: ref
:text-align: center

Probabilistic forecasting

:::

:::{grid-item-card}
:img-top: examples/forecasting/img/hierarchytree_grouped.png
:link: /examples/forecasting/forecasting_hierarchical_global.ipynb
:link-type: ref
:text-align: center

Hierarchical, global, and panel forecasting

:::

:::{grid-item-card}
:link: /examples/forecasting/forecasting_sklearn.ipynb
:link-type: ref
:text-align: center

Forecasting with aeon and scikit learn

:::

::::

## Classification

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: examples/classification/img/tsc.png
:link: /examples/classification/classification.ipynb
:link-type: ref
:text-align: center

Overview of Time Series Classification (TSC)

:::

:::{grid-item-card}
:img-top: examples/classification/img/convolution.png
:link: /examples/classification/convolution_based.ipynb
:link-type: ref
:text-align: center

Convolution based TSC

:::

:::{grid-item-card}
:img-top: examples/classification/img/it.png
:link: /examples/classification/deep_learning.ipynb
:link-type: ref
:text-align: center
Deep learning based TSC

:::

:::{grid-item-card}
:img-top: examples/classification/img/hist.png
:link: /examples/classification/dictionary_based.ipynb
:link-type: ref
:text-align: center

Dictionary based TSC

:::

:::{grid-item-card}
:img-top: examples/classification/img/dtw.png
:link: /examples/classification/distance_based.ipynb
:link-type: ref
:text-align: center

Distance based TSC

:::

:::{grid-item-card}
:img-top: examples/classification/img/pipeline.png
:link: /examples/classification/feature_based.ipynb
:link-type: ref
:text-align: center

Feature based TSC

:::

:::{grid-item-card}
:img-top: examples/classification/img/hc2.png
:link: /examples/classification/hybrid.ipynb
:link-type: ref
:text-align: center

Hybrid TSC

:::

:::{grid-item-card}
:img-top: examples/classification/img/interval.png
:link: /examples/classification/interval_based.ipynb
:link-type: ref
:text-align: center

Interval based TSC

:::

:::{grid-item-card}
:img-top: examples/classification/img/shapelet.png
:link: /examples/classification/shapelet_based.ipynb
:link-type: ref
:text-align: center

Shapelet based TSC

:::

:::{grid-item-card}
:link: /examples/classification/early_classification.ipynb
:link-type: ref
:text-align: center

Early TSC

:::

:::{grid-item-card}
:link: /examples/classification/channel_selection.ipynb
:link-type: ref
:text-align: center

Channel selection in multivariate TSC

:::

::::

## Regression
::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: /examples/regression/img/tser.png
:link: /examples/regression/regression.ipynb
:link-type: ref
:text-align: center

Overview of Time Series Regression (TSR)

:::

::::

## Clustering

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: examples/clustering/img/tscl.png
:link: /examples/clustering/partitional_clustering.ipynb
:link-type: ref
:text-align: center

Overview of Time Series Clustering (TSCL)

:::

::::

## Transformation

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: examples/transformations/img/transformation.png
:link: /examples/transformations/transformation.ipynb
:link-type: ref
:text-align: center

Overview of Transformation

:::

:::{grid-item-card}
:img-top: examples/transformations/img/tsfresh.png
:link: /examples/transformations/feature_extraction_with_tsfresh.ipynb
:link-type: ref
:text-align: center

Feature based

:::

:::{grid-item-card}
:img-top: examples/transformations/img/rocket.png
:link: /examples/transformations/rocket.ipynb
:link-type: ref
:text-align: center

Convolution based

:::

:::{grid-item-card}
:img-top: examples/transformations/img/leaves_shapelets.png
:link: /examples/transformations/shapelets.ipynb
:link-type: ref
:text-align: center

Shapelet based

:::

:::{grid-item-card}
:img-top: examples/transformations/img/interpolation.png
:link: /examples/transformations/interpolation.ipynb
:link-type: ref
:text-align: center

Interpolation

:::


:::{grid-item-card}
:img-top: examples/transformations/img/plateau.png
:link: /examples/transformations/plateau_finder.ipynb
:link-type: ref
:text-align: center

Plateau finding

:::

:::{grid-item-card}
:img-top: examples/transformations/img/signature.png
:link: /examples/transformations/signature_method.ipynb
:link-type: ref
:text-align: center

Signature method

:::

:::{grid-item-card}
:img-top: examples/transformations/img/theta.png
:link: /examples/transformations/theta_transform.ipynb
:link-type: ref
:text-align: center

Theta transform

:::

::::

## Annotation

::::{grid} 2 4 4 4
:gutter: 1


:::{grid-item-card}
:img-top: examples/annotation/img/segmentation_use_cases.png
:link: /examples/annotation/annotation.ipynb
:link-type: ref
:text-align: center

Intro to annotation

:::

:::{grid-item-card}
:img-top: examples/annotation/img/clasp.png
:link: /examples/annotation/segmentation_with_clasp.ipynb
:link-type: ref
:text-align: center

ClaSP segmentation

:::

:::{grid-item-card}
:link: /examples/annotation/hidalgo_segmentation.ipynb
:link-type: ref
:text-align: center

Hidalgo segmentation

:::


::::


## Distances

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: examples/distances/img/dtw_vis.png
:link: /examples/distances/distances.ipynb
:link-type: ref
:text-align: center

Distance functions

:::


:::{grid-item-card}
:img-top: examples/distances/img/svm.png
:link: /examples/distances/sklearn_distances.ipynb
:link-type: ref
:text-align: center

Using aeon distances with scikit-learn

::::

## Data Formatting and Loading

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: examples/datasets/img/data.png
:link: /examples/datasets/datasets.ipynb
:link-type: ref
:text-align: center

Data in aeon

:::

:::{grid-item-card}
:link: /examples/datasets/data_structures.ipynb
:link-type: ref
:text-align: center

Data structures and containers used in aeon

:::

:::{grid-item-card}
:link: /examples/datasets/data_conversions.ipynb
:link-type: ref
:text-align: center

Conversions between data structures

:::

:::{grid-item-card}
:link: /examples/datasets/data_loading.ipynb
:link-type: ref
:text-align: center

How series are stored in file and loaded into memory

:::

:::{grid-item-card}
:link: /examples/datasets/provided_data.ipynb
:link-type: ref
:text-align: center

Example data sets

:::

:::

:::{grid-item-card}
:link: /examples/datasets/load_data_from_web.ipynb
:link-type: ref
:text-align: center

Loading data from the web

:::

::::

## Benchmarking

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:link: /examples/benchmarking/benchmarkings.ipynb
:link-type: ref
:text-align: center

Benchmarking algorithms

:::

:::{grid-item-card}
:link: /examples/benchmarking/results_loading.ipynb
:link-type: ref
:text-align: center

Geting published results

:::

::::

==> aeon-0.5.0.tar.gz: aeon-0.5.0/docs/examples.md <==
# Examples

## Forecasting

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: /examples/forecasting/img/forecasting.png
:class-img-top: aeon-card-image-m
:link: /examples/forecasting/forecasting.ipynb
:link-type: ref
:text-align: center

Overview of forecasting

:::

:::{grid-item-card}
:img-top: examples/forecasting/img/proba.png
:class-img-top: aeon-card-image-m
:link: /examples/forecasting/forecasting_proba.ipynb
:link-type: ref
:text-align: center

Probabilistic forecasting

:::

:::{grid-item-card}
:img-top: examples/forecasting/img/hierarchytree_grouped.png
:class-img-top: aeon-card-image-m
:link: /examples/forecasting/forecasting_hierarchical_global.ipynb
:link-type: ref
:text-align: center

Hierarchical, global, and panel forecasting

:::

:::{grid-item-card}
:img-top: examples/forecasting/img/forecasting-to-regression-reduction.png
:class-img-top: aeon-card-image-m
:link: /examples/forecasting/forecasting_sklearn.ipynb
:link-type: ref
:text-align: center

Forecasting with aeon and scikit-learn

:::

:::{grid-item-card}
:img-top: examples/forecasting/img/splitter.png
:class-img-top: aeon-card-image-m
:link: /examples/forecasting/window_splitters.ipynb
:link-type: ref
:text-align: center

Window splitters for forecasting

:::

::::

## Classification

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: examples/classification/img/tsc.png
:class-img-top: aeon-card-image-m
:link: /examples/classification/classification.ipynb
:link-type: ref
:text-align: center

Overview of Time Series Classification (TSC)

:::

:::{grid-item-card}
:img-top: examples/classification/img/convolution.png
:class-img-top: aeon-card-image-m
:link: /examples/classification/convolution_based.ipynb
:link-type: ref
:text-align: center

Convolution based TSC

:::

:::{grid-item-card}
:img-top: examples/classification/img/it.png
:class-img-top: aeon-card-image-m
:link: /examples/classification/deep_learning.ipynb
:link-type: ref
:text-align: center
Deep learning based TSC

:::

:::{grid-item-card}
:img-top: examples/classification/img/hist.png
:class-img-top: aeon-card-image-m
:link: /examples/classification/dictionary_based.ipynb
:link-type: ref
:text-align: center

Dictionary based TSC

:::

:::{grid-item-card}
:img-top: examples/classification/img/dtw.png
:class-img-top: aeon-card-image-m
:link: /examples/classification/distance_based.ipynb
:link-type: ref
:text-align: center

Distance based TSC

:::

:::{grid-item-card}
:img-top: examples/classification/img/pipeline.png
:class-img-top: aeon-card-image-m
:link: /examples/classification/feature_based.ipynb
:link-type: ref
:text-align: center

Feature based TSC

:::

:::{grid-item-card}
:img-top: examples/classification/img/hc2.png
:class-img-top: aeon-card-image-m
:link: /examples/classification/hybrid.ipynb
:link-type: ref
:text-align: center

Hybrid TSC

:::

:::{grid-item-card}
:img-top: examples/classification/img/interval.png
:class-img-top: aeon-card-image-m
:link: /examples/classification/interval_based.ipynb
:link-type: ref
:text-align: center

Interval based TSC

:::

:::{grid-item-card}
:img-top: examples/classification/img/shapelet.png
:class-img-top: aeon-card-image-m
:link: /examples/classification/shapelet_based.ipynb
:link-type: ref
:text-align: center

Shapelet based TSC

:::

:::{grid-item-card}
:img-top: images/logo/aeon-logo-blue-2-transparent.png
:class-img-top: aeon-card-image-m
:link: /examples/classification/early_classification.ipynb
:link-type: ref
:text-align: center

Early TSC

:::

:::{grid-item-card}
:img-top: images/logo/aeon-logo-blue-2-transparent.png
:class-img-top: aeon-card-image-m
:link: /examples/classification/channel_selection.ipynb
:link-type: ref
:text-align: center

Channel selection in multivariate TSC

:::

::::

## Regression
::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: /examples/regression/img/tser.png
:class-img-top: aeon-card-image-m
:link: /examples/regression/regression.ipynb
:link-type: ref
:text-align: center

Overview of Time Series Regression (TSR)

:::

::::

## Clustering

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: examples/clustering/img/tscl.png
:class-img-top: aeon-card-image-m
:link: /examples/clustering/partitional_clustering.ipynb
:link-type: ref
:text-align: center

Overview of Time Series Clustering (TSCL)

:::

::::

## Transformation

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: examples/transformations/img/transformation.png
:class-img-top: aeon-card-image-m
:link: /examples/transformations/transformation.ipynb
:link-type: ref
:text-align: center

Overview of Transformation

:::

:::{grid-item-card}
:img-top: examples/transformations/img/tsfresh.png
:class-img-top: aeon-card-image-m
:link: /examples/transformations/feature_extraction_with_tsfresh.ipynb
:link-type: ref
:text-align: center

Feature based

:::

:::{grid-item-card}
:img-top: examples/transformations/img/rocket.png
:class-img-top: aeon-card-image-m
:link: /examples/transformations/rocket.ipynb
:link-type: ref
:text-align: center

Convolution based

:::

:::{grid-item-card}
:img-top: examples/transformations/img/leaves_shapelets.png
:class-img-top: aeon-card-image-m
:link: /examples/transformations/shapelets.ipynb
:link-type: ref
:text-align: center

Shapelet based

:::

:::{grid-item-card}
:img-top: examples/transformations/img/interpolation.png
:class-img-top: aeon-card-image-m
:link: /examples/transformations/interpolation.ipynb
:link-type: ref
:text-align: center

Interpolation

:::


:::{grid-item-card}
:img-top: examples/transformations/img/plateau.png
:class-img-top: aeon-card-image-m
:link: /examples/transformations/plateau_finder.ipynb
:link-type: ref
:text-align: center

Plateau finding

:::

:::{grid-item-card}
:img-top: examples/transformations/img/signature.png
:class-img-top: aeon-card-image-m
:link: /examples/transformations/signature_method.ipynb
:link-type: ref
:text-align: center

Signature method

:::

:::{grid-item-card}
:img-top: examples/transformations/img/theta.png
:class-img-top: aeon-card-image-m
:link: /examples/transformations/theta_transform.ipynb
:link-type: ref
:text-align: center

Theta transform

:::

::::

## Annotation

::::{grid} 2 4 4 4
:gutter: 1


:::{grid-item-card}
:img-top: examples/annotation/img/segmentation_use_cases.png
:class-img-top: aeon-card-image-m
:link: /examples/annotation/annotation.ipynb
:link-type: ref
:text-align: center

Intro to annotation

:::

:::{grid-item-card}
:img-top: examples/annotation/img/clasp.png
:class-img-top: aeon-card-image-m
:link: /examples/annotation/segmentation_with_clasp.ipynb
:link-type: ref
:text-align: center

ClaSP segmentation

:::

:::{grid-item-card}
:img-top: images/logo/aeon-logo-blue-2-transparent.png
:class-img-top: aeon-card-image-m
:link: /examples/annotation/hidalgo_segmentation.ipynb
:link-type: ref
:text-align: center

Hidalgo segmentation

:::


::::


## Distances

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: examples/distances/img/dtw_vis.png
:class-img-top: aeon-card-image-m
:link: /examples/distances/distances.ipynb
:link-type: ref
:text-align: center

Distance functions

:::


:::{grid-item-card}
:img-top: examples/distances/img/svm.png
:class-img-top: aeon-card-image-m
:link: /examples/distances/sklearn_distances.ipynb
:link-type: ref
:text-align: center

Using aeon distances with scikit-learn

::::

## Data Formatting and Loading

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: examples/datasets/img/data.png
:class-img-top: aeon-card-image-m
:link: /examples/datasets/datasets.ipynb
:link-type: ref
:text-align: center

Data in aeon

:::

:::{grid-item-card}
:img-top: images/logo/aeon-logo-blue-2-transparent.png
:class-img-top: aeon-card-image-m
:link: /examples/datasets/data_structures.ipynb
:link-type: ref
:text-align: center

Data structures and containers used in aeon

:::

:::{grid-item-card}
:img-top: images/logo/aeon-logo-blue-2-transparent.png
:class-img-top: aeon-card-image-m
:link: /examples/datasets/data_conversions.ipynb
:link-type: ref
:text-align: center

Conversions between data structures

:::

:::{grid-item-card}
:img-top: images/logo/aeon-logo-blue-2-transparent.png
:class-img-top: aeon-card-image-m
:link: /examples/datasets/data_loading.ipynb
:link-type: ref
:text-align: center

How series are stored in file and loaded into memory

:::

:::{grid-item-card}
:img-top: images/logo/aeon-logo-blue-2-transparent.png
:class-img-top: aeon-card-image-m
:link: /examples/datasets/provided_data.ipynb
:link-type: ref
:text-align: center

Example data sets

:::

:::

:::{grid-item-card}
:img-top: images/logo/aeon-logo-blue-2-transparent.png
:class-img-top: aeon-card-image-m
:link: /examples/datasets/load_data_from_web.ipynb
:link-type: ref
:text-align: center

Loading data from the web

:::

::::

## Benchmarking

::::{grid} 2 4 4 4
:gutter: 1

:::{grid-item-card}
:img-top: images/logo/aeon-logo-blue-2-transparent.png
:class-img-top: aeon-card-image-m
:link: /examples/benchmarking/benchmarkings.ipynb
:link-type: ref
:text-align: center

Benchmarking algorithms

:::

:::{grid-item-card}
:img-top: images/logo/aeon-logo-blue-2-transparent.png
:class-img-top: aeon-card-image-m
:link: /examples/benchmarking/results_loading.ipynb
:link-type: ref
:text-align: center

Geting published results

:::

::::
